import cn.estsh.i3plus.pojo.base.bean.DdlPackBean
import cn.estsh.i3plus.pojo.base.tool.DdlPreparedPack
import cn.estsh.i3plus.pojo.mes.bean.MesEquipment
import cn.estsh.i3plus.pojo.mes.bean.MesProduceSn
import cn.estsh.i3plus.pojo.mes.bean.MesWorkOrder
import cn.estsh.i3plus.pojo.mes.dbinterface.MesInterfaceDataMapper
import cn.estsh.i3plus.pojo.mes.repository.MesEquipmentRepository
import cn.estsh.i3plus.pojo.mes.repository.MesProduceSnRepository
import cn.estsh.i3plus.pojo.mes.repository.MesWorkOrderRepository
import org.slf4j.Logger
import org.slf4j.LoggerFactory
import org.springframework.beans.factory.annotation.Autowired

/**
 * @Description : 加工记录同步 MES2PISCES
 * @Reference :
 * @Author : wangjie
 * @CreateDate 2024/7/12 12:28
 * @Modify:
 * */
class MesProductionRecordToPisces {

    public static final Logger LOGGER = LoggerFactory.getLogger(MesProductionRecordToPisces.class)

    @Autowired
    private MesEquipmentRepository equipmentRepository;

    @Autowired
    private MesProduceSnRepository produceSnRepository;

    @Autowired
    private MesWorkOrderRepository workOrderRepository;

    def filterData(MesInterfaceDataMapper mapper, List<Map<String, Object>> srcData) throws Exception {
        if (srcData == null || srcData.size() == 0) {
            return srcData
        }

        for (Map<String, Object> rowMap : srcData) {

            String productSn = String.valueOf(rowMap.get("product_sn"));
            String partNo = String.valueOf(rowMap.get("part_no"));

            MesProduceSn produceSnDb = getProduceSnDb(mapper.getOrganizeCode(), productSn, partNo);
            if (!Objects.isNull(produceSnDb)) {
                rowMap.put("BARCODE_ID", produceSnDb.getId())
            }

            String workOrderNo = String.valueOf(rowMap.get("work_order_no"));
            MesWorkOrder workOrderDb = getWorkOrderDb(mapper.getOrganizeCode(), workOrderNo);
            if (!Objects.isNull(workOrderDb)) {
                rowMap.put("WORK_ORDER_FID", workOrderDb.getFid())
            }

            String equipmentCode = String.valueOf(rowMap.get("equipment_code"));
            MesEquipment equipmentDb = getEquipmentDb(mapper.getOrganizeCode(), equipmentCode);
            if (!Objects.isNull(equipmentDb)) {
                rowMap.put("EQUIPMENT_ID", equipmentDb.getEquipId())
            }

        }

        return srcData;
    }

    def getProduceSnDb(String organizeCode, String productSn, String partNo) {
        DdlPackBean ddlPackBean = DdlPackBean.getDdlPackBean(organizeCode);
        DdlPreparedPack.getStringEqualPack(productSn, "productSn", ddlPackBean);
        DdlPreparedPack.getStringEqualPack(partNo, "partNo", ddlPackBean);
        MesProduceSn produceSnDb = produceSnRepository.getByProperty(ddlPackBean);
        return produceSnDb;
    }

    MesWorkOrder getWorkOrderDb(String organizeCode, String workOrderNo) {
        DdlPackBean ddlPackBean = DdlPackBean.getDdlPackBean(organizeCode);
        DdlPreparedPack.getStringEqualPack(workOrderNo, "workOrderNo", ddlPackBean);
        MesWorkOrder workOrderDb = workOrderRepository.getByProperty(ddlPackBean);
        return workOrderDb;
    }

    def getEquipmentDb(String organizeCode, String equipmentCode) {
        DdlPackBean ddlPackBean = DdlPackBean.getDdlPackBean(organizeCode);
        DdlPreparedPack.getStringEqualPack(equipmentCode, "equipmentCode", ddlPackBean);
        MesEquipment equipmentDb = equipmentRepository.getByProperty(ddlPackBean);
        return equipmentDb;
    }

}